==> amzn-amazon-pay-module-1.1.0.zip: Domain/AmazonGetOrderDetailsResponse.php <==
<?php
/**
 * Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
namespace Amazon\Payment\Domain;

use Amazon\Core\Exception\AmazonServiceUnavailableException;
use Amazon\Payment\Domain\Details\AmazonOrderDetails;
use Amazon\Payment\Domain\Details\AmazonOrderDetailsFactory;
use PayWithAmazon\ResponseInterface;

class AmazonGetOrderDetailsResponse
{
    /**
     * @var AmazonOrderDetails
     */
    protected $details;

    public function __construct(ResponseInterface $response, AmazonOrderDetailsFactory $amazonOrderDetailsFactory)
    {
        $data = $response->toArray();

        if (200 != $data['ResponseStatus']) {
            throw new AmazonServiceUnavailableException();
        }

        $details = $data['GetOrderReferenceDetailsResult']['OrderReferenceDetails'];

        $this->details = $amazonOrderDetailsFactory->create([
            'details' => $details
        ]);
    }

    /**
     * @return AmazonOrderDetails
     */
    public function getDetails()
    {
        return $this->details;
    }
}

==> amzn-amazon-pay-module-1.2.2.zip: Domain/AmazonGetOrderDetailsResponse.php <==
<?php
/**
 * Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
namespace Amazon\Payment\Domain;

use Amazon\Core\Exception\AmazonServiceUnavailableException;
use Amazon\Payment\Domain\Details\AmazonOrderDetails;
use Amazon\Payment\Domain\Details\AmazonOrderDetailsFactory;
use AmazonPay\ResponseInterface;

class AmazonGetOrderDetailsResponse
{
    /**
     * @var AmazonOrderDetails
     */
    protected $details;

    public function __construct(ResponseInterface $response, AmazonOrderDetailsFactory $amazonOrderDetailsFactory)
    {
        $data = $response->toArray();

        if (200 != $data['ResponseStatus']) {
            throw new AmazonServiceUnavailableException();
        }

        $details = $data['GetOrderReferenceDetailsResult']['OrderReferenceDetails'];

        $this->details = $amazonOrderDetailsFactory->create([
            'details' => $details
        ]);
    }

    /**
     * @return AmazonOrderDetails
     */
    public function getDetails()
    {
        return $this->details;
    }
}
